==> zio-aws-workspacesweb_3-5.17.124.1-sources.jar: zio/aws/workspacesweb/model/GetUserSettingsResponse.scala <==
package zio.aws.workspacesweb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetUserSettingsResponse(
    userSettings: Option[zio.aws.workspacesweb.model.UserSettings] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse = {
    import GetUserSettingsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse
      .builder()
      .optionallyWith(userSettings.map(value => value.buildAwsValue()))(
        _.userSettings
      )
      .build()
  }
  def asReadOnly: zio.aws.workspacesweb.model.GetUserSettingsResponse.ReadOnly =
    zio.aws.workspacesweb.model.GetUserSettingsResponse.wrap(buildAwsValue())
}
object GetUserSettingsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspacesweb.model.GetUserSettingsResponse =
      zio.aws.workspacesweb.model
        .GetUserSettingsResponse(userSettings.map(value => value.asEditable))
    def userSettings: Option[zio.aws.workspacesweb.model.UserSettings.ReadOnly]
    def getUserSettings: ZIO[
      Any,
      AwsError,
      zio.aws.workspacesweb.model.UserSettings.ReadOnly
    ] = AwsError.unwrapOptionField("userSettings", userSettings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse
  ) extends zio.aws.workspacesweb.model.GetUserSettingsResponse.ReadOnly {
    override val userSettings
        : Option[zio.aws.workspacesweb.model.UserSettings.ReadOnly] = scala
      .Option(impl.userSettings())
      .map(value => zio.aws.workspacesweb.model.UserSettings.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse
  ): zio.aws.workspacesweb.model.GetUserSettingsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-workspacesweb_3-5.17.211.1-sources.jar: zio/aws/workspacesweb/model/GetUserSettingsResponse.scala <==
package zio.aws.workspacesweb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetUserSettingsResponse(
    userSettings: Optional[zio.aws.workspacesweb.model.UserSettings] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse = {
    import GetUserSettingsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse
      .builder()
      .optionallyWith(userSettings.map(value => value.buildAwsValue()))(
        _.userSettings
      )
      .build()
  }
  def asReadOnly: zio.aws.workspacesweb.model.GetUserSettingsResponse.ReadOnly =
    zio.aws.workspacesweb.model.GetUserSettingsResponse.wrap(buildAwsValue())
}
object GetUserSettingsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspacesweb.model.GetUserSettingsResponse =
      zio.aws.workspacesweb.model
        .GetUserSettingsResponse(userSettings.map(value => value.asEditable))
    def userSettings
        : Optional[zio.aws.workspacesweb.model.UserSettings.ReadOnly]
    def getUserSettings: ZIO[
      Any,
      AwsError,
      zio.aws.workspacesweb.model.UserSettings.ReadOnly
    ] = AwsError.unwrapOptionField("userSettings", userSettings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse
  ) extends zio.aws.workspacesweb.model.GetUserSettingsResponse.ReadOnly {
    override val userSettings
        : Optional[zio.aws.workspacesweb.model.UserSettings.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userSettings())
        .map(value => zio.aws.workspacesweb.model.UserSettings.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspacesweb.model.GetUserSettingsResponse
  ): zio.aws.workspacesweb.model.GetUserSettingsResponse.ReadOnly = new Wrapper(
    impl
  )
}
